<?php
namespace Teknisa\CMP\Services;

use Doctrine\ORM\EntityManager;

/**
 * Class ArquivosService
 * @package Teknisa\CMP\Services
 */
class ArquivosService
{
    
    /**
     * @param EntityManager $entityManager
     */
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    public function getFileServerUrl()
    {
        return $this->_fileServerUrl;
    }
    /**
     * @desc   Download Arquivo
     * @param  $arquivo
     * @throws \Exception
     */
    public function downloadArquivo($arquivo) {
        try {
            if (isset($arquivo) && file_exists($arquivo)) {
                $tipo = null;

                switch (strtolower(substr(strrchr(basename($arquivo),"."),1))) {
                    case "gif" : $tipo="image/gif"                    ; break;
                    case "png" : $tipo="image/png"                    ; break;
                    case "jpg" : $tipo="image/jpg"                    ; break;
                    case "wma" : $tipo="audio/mime"                   ; break;
                    case "txt" : $tipo="text/plain"                   ; break;
                    case "rem" : $tipo="text/plain"                   ; break;
                    case "mp3" : $tipo="audio/mpeg"                   ; break;
                    case "mp4" : $tipo="video/mpeg-4"                 ; break;
                    case "pdf" : $tipo="application/pdf"              ; break;
                    case "zip" : $tipo="application/zip"              ; break;
                    case "doc" : $tipo="application/msword"           ; break;
                    case "xls" : $tipo="application/vnd.ms-excel"     ; break;
                    case "exe" : $tipo="application/octet-stream"     ; break;
                    case "ppt" : $tipo="application/vnd.ms-powerpoint"; break;
                    case "php" :                                      ; break;
                    case "htm" :                                      ; break;
                    case "html":                                      ; break;
                }

                header("Content-Type: ".$tipo);
                header("Content-Length: ".filesize($arquivo));
                header("Content-Disposition: attachment; filename=".basename($arquivo));
                
                readfile($arquivo);
                unlink($arquivo);

                die();
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function downloadArquivoAnexo($arquivo)
    {
        try {
            if (isset($arquivo) && file_exists($arquivo)) {
                $tipo = null;

                switch(strtolower(substr(strrchr(basename($arquivo),"."),1))) {
                    case "gif" : $tipo="image/gif"                    ; break;
                    case "png" : $tipo="image/png"                    ; break;
                    case "jpg" : $tipo="image/jpg"                    ; break;
                    case "wma" : $tipo="audio/mime"                   ; break;
                    case "txt" : $tipo="text/plain"                   ; break;
                    case "rem" : $tipo="text/plain"                   ; break;
                    case "mp3" : $tipo="audio/mpeg"                   ; break;
                    case "mp4" : $tipo="video/mpeg-4"                 ; break;
                    case "pdf" : $tipo="application/pdf"              ; break;
                    case "zip" : $tipo="application/zip"              ; break;
                    case "doc" : $tipo="application/msword"           ; break;
                    case "xls" : $tipo="application/vnd.ms-excel"     ; break;
                    case "exe" : $tipo="application/octet-stream"     ; break;
                    case "ppt" : $tipo="application/vnd.ms-powerpoint"; break;
                    case "php" :                                      ; break;
                    case "htm" :                                      ; break;
                    case "html":                                      ; break;
                }

                header("Content-Type: ".$tipo);
                header("Content-Length: ".filesize($arquivo));
                header("Content-Disposition: attachment; filename=".basename($arquivo));
                readfile($arquivo);
                
                die();
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function downloadArquivoAnexoFileServer($arquivo, $fileName) {
        try {
            if(isset($arquivo)) {
                $contentLenghtArray = array();
                foreach(get_headers($arquivo) as $value) {
                    if(strpos($value, 'Content-Length: ') !== false) {
                    	array_push($contentLenghtArray, str_replace('Content-Length: ', '',$value));
                    }
                };
                
                $contentLenght = max($contentLenghtArray);
                
                $key = $this->hasErrorOnResponse(get_headers($arquivo));
                
                if(is_numeric($key)) {
                    throw new \Exception(get_headers($arquivo)[$key]);
                }
                
                $tipo = null;
    
                switch (strtolower(substr(strrchr(basename($arquivo), "."), 1))) {
                    case "gif" : $tipo="image/gif"                    ; break;
                    case "png" : $tipo="image/png"                    ; break;
                    case "jpg" : $tipo="image/jpg"                    ; break;
                    case "wma" : $tipo="audio/mime"                   ; break;
                    case "txt" : $tipo="text/plain"                   ; break;
                    case "rem" : $tipo="text/plain"                   ; break;
                    case "mp3" : $tipo="audio/mpeg"                   ; break;
                    case "mp4" : $tipo="video/mpeg-4"                 ; break;
                    case "pdf" : $tipo="application/pdf"              ; break;
                    case "zip" : $tipo="application/zip"              ; break;
                    case "doc" : $tipo="application/msword"           ; break;
                    case "xls" : $tipo="application/vnd.ms-excel"     ; break;
                    case "exe" : $tipo="application/octet-stream"     ; break;
                    case "ppt" : $tipo="application/vnd.ms-powerpoint"; break;
                    case "php" :                                      ; break;
                    case "htm" :                                      ; break;
                    case "html":                                      ; break;
                }
                
                header("Content-Type: ".$tipo);
                header("Content-Length: ".$contentLenght);
                header("Content-Disposition: attachment; filename=".basename($fileName));
                readfile($arquivo);
                
                die();
            } else {
                throw new \Exception('URL não definida.');
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function hasErrorOnResponse($headers)
    {
        $errors = [
            'HTTP/1.1 404 Not Found',
            'HTTP/1.1 500 Internal Server Error',
        ];
        
        foreach ($errors as $error) {
            $key = array_search($error, $headers);
            
            if (is_numeric($key)) {
                return $key;
            }
        }
        
        return false;
    }
}
